# TODO
## mcpgateway cli
- [ ] Add stop to `mcpgateway` to kill / stop all processes
- [ ] Issue stopping mcpgateway using ^C (it waits for network connections to stop)

## Translate
- [ ] Add translate to mcpgateway cli

## Docs: README
- [ ]`- -v $(pwd)/data:/app` - this needs /app/db/...
- [ ] Add docs for `--host` and describe macos issues
